@@ -20,7 +20,6 @@ import reframe.core.hooks as hooks
 import reframe.utility as utils
 
 from reframe.core.exceptions import ReframeSyntaxError
-from reframe.core.runtime import runtime
 
 
 class RegressionTestMeta(type):
@@ -141,11 +140,9 @@ class RegressionTestMeta(type):
                         # available in the current class' namespace.
                         for b in self['_rfm_bases']:
                             if key in b._rfm_var_space:
-                                # Store a deep-copy of the variable's
-                                # value and return.
-                                v = b._rfm_var_space[key].default_value
+                                v = variables.ShadowVar(b._rfm_var_space[key])
                                 self._namespace[key] = v
-                                return self._namespace[key]
+                                return v
 
                         # If 'key' is neither a variable nor a parameter,
                         # raise the exception from the base __getitem__.
@@ -424,6 +421,8 @@ class RegressionTestMeta(type):
             obj._rfm_unique_name = fixt_name
             obj._rfm_fixt_data = fixt_data
             obj._rfm_is_fixture = True
+        else:
+            obj._rfm_unique_name = cls.variant_name(variant_num)
 
         # Set the variables passed to the constructor
         for k, v in fixt_vars.items():
@@ -434,7 +433,8 @@ class RegressionTestMeta(type):
         # the init phase
         varinfo = cls.get_variant_info(variant_num, recurse=True)
         for fname, finfo in varinfo['fixtures'].items():
-            if not isinstance(finfo, tuple):
+            fixt = cls.fixture_space[fname]
+            if fixt.action != 'join':
                 setattr(obj, fname, fixtures.FixtureProxy(finfo))
 
         obj.__init__(*args, **kwargs)
@@ -799,20 +799,9 @@ class RegressionTestMeta(type):
         if variant_num is None:
             return name
 
-        if runtime().get_option('general/0/compact_test_names'):
-            if cls.num_variants > 1:
-                width = utils.count_digits(cls.num_variants)
-                name += f'_{variant_num:0{width}}'
-        else:
-            pid, fid = cls._map_variant_num(variant_num)
-
-            # Append the parameters to the name
-            if cls.param_space.params:
-                name += '_' + '_'.join(utils.toalphanum(str(v))
-                                       for v in cls.param_space[pid].values())
-
-            if len(cls.fixture_space) > 1:
-                name += f'_{fid}'
+        if cls.num_variants > 1:
+            width = utils.count_digits(cls.num_variants)
+            name += f'_{variant_num:0{width}}'
 
         return name
 
