@@ -22,15 +22,51 @@ from reframe.core.meta import RegressionTestMeta
 
 
 class JobMeta(RegressionTestMeta, abc.ABCMeta):
-    '''Job metaclass.'''
+    '''Job metaclass.
+
+    :meta private:
+    '''
 
 
-class JobScheduler(abc.ABC):
+class JobSchedulerMeta(abc.ABCMeta):
+    '''Metaclass for JobSchedulers.
+
+    The purpose of this metaclass is to intercept the constructor call and
+    consume the `part_name` argument for setting up the configuration prefix
+    without requiring the users to call `super().__init__()` in their
+    constructors. This allows the base class to have the look and feel of a
+    pure interface.
+
+    :meta private:
+
+    '''
+    def __call__(cls, *args, **kwargs):
+        part_name = kwargs.pop('part_name', None)
+        obj = cls.__new__(cls, *args, **kwargs)
+        if part_name:
+            obj._config_prefix = (
+                f'systems/0/paritions/@{part_name}/sched_options'
+            )
+        else:
+            obj._config_prefix = 'systems/0/sched_options'
+
+        obj.__init__(*args, **kwargs)
+        return obj
+
+
+class JobScheduler(abc.ABC, metaclass=JobSchedulerMeta):
     '''Abstract base class for job scheduler backends.
 
     :meta private:
     '''
 
+    def get_option(self, name):
+        '''Get scheduler-specific option.
+
+        :meta private:
+        '''
+        return runtime.runtime().get_option(f'{self._config_prefix}/{name}')
+
     @abc.abstractmethod
     def make_job(self, *args, **kwargs):
         '''Create a new job to be managed by this scheduler.
@@ -258,7 +294,7 @@ class Job(jsonext.JSONSerializable, metaclass=JobMeta):
     #:
     #:    from reframe.core.backends import getlauncher
     #:
-    #:    @rfm.run_after('setup')
+    #:    @run_after('setup')
     #:    def set_launcher(self):
     #:        self.job.launcher = getlauncher('local')()
     #:
@@ -321,34 +357,45 @@ class Job(jsonext.JSONSerializable, metaclass=JobMeta):
 
     @property
     def name(self):
+        '''The name of this job.'''
         return self._name
 
     @property
     def workdir(self):
+        '''The working directory for this job.'''
         return self._workdir
 
     @property
     def cli_options(self):
+        '''The scheduler options passed through the :option:`-J` command line
+        options.'''
         return self._cli_options
 
     @property
     def script_filename(self):
+        '''The filename of the generated job script.'''
         return self._script_filename
 
     @property
     def stdout(self):
+        '''The file where the standard output of the job is saved.'''
         return self._stdout
 
     @property
     def stderr(self):
+        '''The file where the standard error of the job is saved.'''
         return self._stderr
 
     @property
     def sched_flex_alloc_nodes(self):
+        '''The argument of the :option:`--flex-alloc-nodes` command line
+        option.'''
         return self._sched_flex_alloc_nodes
 
     @property
     def sched_access(self):
+        '''The partition's :attr:`~config.systems.partitions.access`
+        options.'''
         return self._sched_access
 
     @property
@@ -375,10 +422,16 @@ class Job(jsonext.JSONSerializable, metaclass=JobMeta):
 
     @property
     def scheduler(self):
+        '''The scheduler where this job is assigned to.'''
         return self._scheduler
 
     @property
     def exception(self):
+        '''The last exception that this job encountered.
+
+        The scheduler will raise this exception the next time the status of
+        this job is queried.
+        '''
         return self._exception
 
     @property
